import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface ExecutorsConfig extends TerraformModuleUserConfig {
    /**
     * The availability zone to create the instance in.
     */
    readonly availabilityZone: string;
    /**
     * Docker registry mirror node disk size in GB.
     * @default 64
     */
    readonly dockerMirrorBootDiskSize?: number;
    /**
     * Persistent Docker registry mirror additional IOPS.
     * @default 3000
     */
    readonly dockerMirrorDiskIops?: number;
    /**
     * DEPRECATED. This is not used anymore.
     * @default 10.0.0.0/16
     */
    readonly dockerMirrorHttpAccessCidrRange?: string;
    /**
     * AMI for the EC2 instance to use. Must be in the same availability zone. Leave empty to use latest compatible with the Sourcegraph version.
     */
    readonly dockerMirrorMachineAmi?: string;
    /**
     * Docker registry mirror node machine type.
     * @default m5.large
     */
    readonly dockerMirrorMachineType?: string;
    /**
     * CIDR range from where SSH access to the EC2 instance is acceptable.
     * @default 0.0.0.0/0
     */
    readonly dockerMirrorSshAccessCidrRange?: string;
    /**
     * The IP to statically assign to the instance. Should be internal.
     * @default 10.0.1.4
     */
    readonly dockerMirrorStaticIp?: string;
    /**
     * Executor node disk additional IOPS.
     * @default 3000
     */
    readonly executorBootDiskIops?: number;
    /**
     * Executor node disk size in GB
     * @default 100
     */
    readonly executorBootDiskSize?: number;
    /**
     * If provided, this docker auth config file will be used to authorize image pulls. See [Using private registries](https://docs.sourcegraph.com/admin/deploy_executors#using-private-registries) for how to configure.
     */
    readonly executorDockerAuthConfig?: string;
    /**
     * The amount of disk space to give to each firecracker VM
     * @default 20GB
     */
    readonly executorFirecrackerDiskSpace?: string;
    /**
     * The amount of memory to give to each firecracker VM
     * @default 12GB
     */
    readonly executorFirecrackerMemory?: string;
    /**
     * The number of CPUs to give to each firecracker VM
     * @default 4
     */
    readonly executorFirecrackerNumCpus?: number;
    /**
     * DEPRECATED. This is not used anymore.
     * @default 0.0.0.0/0
     */
    readonly executorHttpAccessCidrRange?: string;
    /**
     * A label tag to add to all the executors. Can be used for filtering out the right instances in stackdriver monitoring.
     */
    readonly executorInstanceTag: string;
    /**
     * The amount of memory to allocate to each virtual machine or container
     * @default 12GB
     */
    readonly executorJobMemory?: string;
    /**
     * The number of CPUs to allocate to each virtual machine or container
     * @default 4
     */
    readonly executorJobNumCpus?: number;
    /**
     * The amount of jobs a single instance should have in queue. Used for autoscaling.
     * @default 360
     */
    readonly executorJobsPerInstanceScaling?: number;
    /**
     * Executor node machine disk image to use for creating the boot volume. Leave empty to use latest compatible with the Sourcegraph version.
     */
    readonly executorMachineImage?: string;
    /**
     * Executor node machine type.
     * @default c5n.metal
     */
    readonly executorMachineType?: string;
    /**
     * The maximum time that can be spent by the worker dequeueing records to be handled
     * @default 2h
     */
    readonly executorMaxActiveTime?: string;
    /**
     * The maximum number of executor instances to run in the autoscaling group.
     * @default 1
     */
    readonly executorMaxReplicas?: number;
    /**
     * The number of jobs to run concurrently per executor instance
     * @default 18
     */
    readonly executorMaximumNumJobs?: number;
    /**
     * The maximum wall time that can be spent on a single job
     * @default 30m
     */
    readonly executorMaximumRuntimePerJob?: string;
    /**
     * The value for environment by which to filter the custom metrics.
     */
    readonly executorMetricsEnvironmentLabel: string;
    /**
     * The minimum number of executor instances to run in the autoscaling group.
     * @default 1
     */
    readonly executorMinReplicas?: number;
    /**
     * The maximum number of jobs that will be dequeued by the worker
     * @default 1800
     */
    readonly executorNumTotalJobs?: number;
    /**
     * Whether to use preemptible machines instead of standard machines; usually way cheaper but might be terminated at any time
     */
    readonly executorPreemptibleMachines?: boolean;
    /**
     * The queue from which the executor should dequeue jobs.
     */
    readonly executorQueueName: string;
    /**
     * An optional prefix to add to all resources created.
     */
    readonly executorResourcePrefix?: string;
    /**
     * The shared password used to authenticate requests to the internal executor proxy.
     */
    readonly executorSourcegraphExecutorProxyPassword: string;
    /**
     * The externally accessible URL of the target Sourcegraph instance.
     */
    readonly executorSourcegraphExternalUrl: string;
    /**
     * CIDR range from where SSH access to the EC2 instances is acceptable.
     * @default 0.0.0.0/0
     */
    readonly executorSshAccessCidrRange?: string;
    /**
     * Whether to isolate commands in virtual machines
     * @default true
     */
    readonly executorUseFirecracker?: boolean;
    /**
     * If not provided, there will be no permissions boundary on IAM roles and users created. The ARN of a policy to use for permissions boundaries with IAM roles and users.
     */
    readonly permissionsBoundaryArn?: string;
    /**
     * If true, the executors and docker mirror will live in a private subnet and communicate with the internet through NAT.
     */
    readonly privateNetworking?: boolean;
    /**
     * Use randomized names for resources. Deployments using the legacy naming convention will be updated in-place with randomized names when enabled.
     */
    readonly randomizeResourceNames?: boolean;
    /**
     * If provided, the default security groups will not be created. The ID of the security group to associate the Docker Mirror network and the Launch Template network with.
     */
    readonly securityGroupId?: string;
}
/**
 * Defines an Executors based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/sourcegraph/executors/aws/~> 5.0.1 sourcegraph/executors/aws}
 */
export declare class Executors extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: ExecutorsConfig);
    get availabilityZone(): string;
    set availabilityZone(value: string);
    get dockerMirrorBootDiskSize(): number | undefined;
    set dockerMirrorBootDiskSize(value: number | undefined);
    get dockerMirrorDiskIops(): number | undefined;
    set dockerMirrorDiskIops(value: number | undefined);
    get dockerMirrorHttpAccessCidrRange(): string | undefined;
    set dockerMirrorHttpAccessCidrRange(value: string | undefined);
    get dockerMirrorMachineAmi(): string | undefined;
    set dockerMirrorMachineAmi(value: string | undefined);
    get dockerMirrorMachineType(): string | undefined;
    set dockerMirrorMachineType(value: string | undefined);
    get dockerMirrorSshAccessCidrRange(): string | undefined;
    set dockerMirrorSshAccessCidrRange(value: string | undefined);
    get dockerMirrorStaticIp(): string | undefined;
    set dockerMirrorStaticIp(value: string | undefined);
    get executorBootDiskIops(): number | undefined;
    set executorBootDiskIops(value: number | undefined);
    get executorBootDiskSize(): number | undefined;
    set executorBootDiskSize(value: number | undefined);
    get executorDockerAuthConfig(): string | undefined;
    set executorDockerAuthConfig(value: string | undefined);
    get executorFirecrackerDiskSpace(): string | undefined;
    set executorFirecrackerDiskSpace(value: string | undefined);
    get executorFirecrackerMemory(): string | undefined;
    set executorFirecrackerMemory(value: string | undefined);
    get executorFirecrackerNumCpus(): number | undefined;
    set executorFirecrackerNumCpus(value: number | undefined);
    get executorHttpAccessCidrRange(): string | undefined;
    set executorHttpAccessCidrRange(value: string | undefined);
    get executorInstanceTag(): string;
    set executorInstanceTag(value: string);
    get executorJobMemory(): string | undefined;
    set executorJobMemory(value: string | undefined);
    get executorJobNumCpus(): number | undefined;
    set executorJobNumCpus(value: number | undefined);
    get executorJobsPerInstanceScaling(): number | undefined;
    set executorJobsPerInstanceScaling(value: number | undefined);
    get executorMachineImage(): string | undefined;
    set executorMachineImage(value: string | undefined);
    get executorMachineType(): string | undefined;
    set executorMachineType(value: string | undefined);
    get executorMaxActiveTime(): string | undefined;
    set executorMaxActiveTime(value: string | undefined);
    get executorMaxReplicas(): number | undefined;
    set executorMaxReplicas(value: number | undefined);
    get executorMaximumNumJobs(): number | undefined;
    set executorMaximumNumJobs(value: number | undefined);
    get executorMaximumRuntimePerJob(): string | undefined;
    set executorMaximumRuntimePerJob(value: string | undefined);
    get executorMetricsEnvironmentLabel(): string;
    set executorMetricsEnvironmentLabel(value: string);
    get executorMinReplicas(): number | undefined;
    set executorMinReplicas(value: number | undefined);
    get executorNumTotalJobs(): number | undefined;
    set executorNumTotalJobs(value: number | undefined);
    get executorPreemptibleMachines(): boolean | undefined;
    set executorPreemptibleMachines(value: boolean | undefined);
    get executorQueueName(): string;
    set executorQueueName(value: string);
    get executorResourcePrefix(): string | undefined;
    set executorResourcePrefix(value: string | undefined);
    get executorSourcegraphExecutorProxyPassword(): string;
    set executorSourcegraphExecutorProxyPassword(value: string);
    get executorSourcegraphExternalUrl(): string;
    set executorSourcegraphExternalUrl(value: string);
    get executorSshAccessCidrRange(): string | undefined;
    set executorSshAccessCidrRange(value: string | undefined);
    get executorUseFirecracker(): boolean | undefined;
    set executorUseFirecracker(value: boolean | undefined);
    get permissionsBoundaryArn(): string | undefined;
    set permissionsBoundaryArn(value: string | undefined);
    get privateNetworking(): boolean | undefined;
    set privateNetworking(value: boolean | undefined);
    get randomizeResourceNames(): boolean | undefined;
    set randomizeResourceNames(value: boolean | undefined);
    get securityGroupId(): string | undefined;
    set securityGroupId(value: string | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
