import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface ExecutorsDockerMirrorConfig extends TerraformModuleUserConfig {
    /**
     * If false, no public IP will be associated with the executors.
     * @default true
     */
    readonly assignPublicIp?: boolean;
    /**
     * Docker registry mirror node disk size in GB.
     * @default 32
     */
    readonly bootDiskSize?: number;
    /**
     * Persistent Docker registry mirror additional IOPS.
     * @default 3000
     */
    readonly diskIops?: number;
    /**
     * Persistent Docker registry mirror disk size in GB.
     * @default 64
     */
    readonly diskSize?: number;
    /**
     * Persistent Docker registry mirror disk throughput in MiB/s.
     * @default 125
     */
    readonly diskThroughput?: number;
    /**
     * If provided, the default security groups will not be created. The ID of the security group to associate the Docker Mirror network with.
     */
    readonly dockerMirrorAccessSecurityGroupId?: string;
    /**
     * CIDR range from where HTTP access to the Docker registry is acceptable.
     * @default 10.0.0.0/16
     */
    readonly httpAccessCidrRange?: string;
    /**
     * DEPRECATED: This is not used anymore.
     * @default 0.0.0.0/0
     */
    readonly httpMetricsAccessCidrRange?: string;
    /**
     * A label tag to add to all the machines; can be used for filtering out the right instances in stackdriver monitoring and in Prometheus instance discovery.
     */
    readonly instanceTagPrefix: string;
    /**
     * AMI for the EC2 instance to use. Must be in the same availability zone. Leave empty to use latest compatible with the Sourcegraph version.
     */
    readonly machineAmi?: string;
    /**
     * Docker registry mirror node machine type.
     * @default m5n.large
     */
    readonly machineType?: string;
    /**
     * If not provided, there will be no permissions boundary on IAM roles and users created. The ARN of a policy to use for permissions boundaries with IAM roles and users.
     */
    readonly permissionsBoundaryArn?: string;
    /**
     * Use randomized names for resources. Deployments using the legacy naming convention will be updated in-place with randomized names when enabled.
     */
    readonly randomizeResourceNames: boolean;
    /**
     * An optional prefix to add to all resources created.
     */
    readonly resourcePrefix?: string;
    /**
     * CIDR range from where SSH access to the EC2 instance is acceptable.
     * @default 10.0.0.0/16
     */
    readonly sshAccessCidrRange?: string;
    /**
     * The IP to statically assign to the instance. Should be internal.
     */
    readonly staticIp: string;
    /**
     * The ID of the subnet within the given VPC to run the instance in.
     */
    readonly subnetId: string;
    /**
     * The ID of the VPC to run the instance in.
     */
    readonly vpcId: string;
}
/**
 * Defines an ExecutorsDockerMirror based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/sourcegraph/executors/aws/~> 5.0.1/submodules/docker-mirror sourcegraph/executors/aws//modules/docker-mirror}
 */
export declare class ExecutorsDockerMirror extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: ExecutorsDockerMirrorConfig);
    get assignPublicIp(): boolean | undefined;
    set assignPublicIp(value: boolean | undefined);
    get bootDiskSize(): number | undefined;
    set bootDiskSize(value: number | undefined);
    get diskIops(): number | undefined;
    set diskIops(value: number | undefined);
    get diskSize(): number | undefined;
    set diskSize(value: number | undefined);
    get diskThroughput(): number | undefined;
    set diskThroughput(value: number | undefined);
    get dockerMirrorAccessSecurityGroupId(): string | undefined;
    set dockerMirrorAccessSecurityGroupId(value: string | undefined);
    get httpAccessCidrRange(): string | undefined;
    set httpAccessCidrRange(value: string | undefined);
    get httpMetricsAccessCidrRange(): string | undefined;
    set httpMetricsAccessCidrRange(value: string | undefined);
    get instanceTagPrefix(): string;
    set instanceTagPrefix(value: string);
    get machineAmi(): string | undefined;
    set machineAmi(value: string | undefined);
    get machineType(): string | undefined;
    set machineType(value: string | undefined);
    get permissionsBoundaryArn(): string | undefined;
    set permissionsBoundaryArn(value: string | undefined);
    get randomizeResourceNames(): boolean;
    set randomizeResourceNames(value: boolean);
    get resourcePrefix(): string | undefined;
    set resourcePrefix(value: string | undefined);
    get sshAccessCidrRange(): string | undefined;
    set sshAccessCidrRange(value: string | undefined);
    get staticIp(): string;
    set staticIp(value: string);
    get subnetId(): string;
    set subnetId(value: string);
    get vpcId(): string;
    set vpcId(value: string);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
