import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface ExecutorsExecutorsConfig extends TerraformModuleUserConfig {
    /**
     * If false, no public IP will be associated with the executors.
     * @default true
     */
    readonly assignPublicIp?: boolean;
    /**
     * Executor node disk additional IOPS.
     * @default 3000
     */
    readonly bootDiskIops?: number;
    /**
     * Executor node disk size in GB.
     * @default 500
     */
    readonly bootDiskSize?: number;
    /**
     * Executor node disk throughput in MiB/s.
     * @default 125
     */
    readonly bootDiskThroughput?: number;
    /**
     * If provided, this docker auth config file will be used to authorize image pulls. See [Using private registries](https://docs.sourcegraph.com/admin/deploy_executors#using-private-registries) for how to configure.
     */
    readonly dockerAuthConfig?: string;
    /**
     * A URL to a docker registry mirror to use (falling back to docker.io).
     */
    readonly dockerRegistryMirror?: string;
    /**
     * A URL to a docker registry mirror node exporter to scrape (optional)
     */
    readonly dockerRegistryMirrorNodeExporterUrl?: string;
    /**
     * The amount of disk space to give to each firecracker VM
     * @default 20GB
     */
    readonly firecrackerDiskSpace?: string;
    /**
     * The amount of memory to give to each firecracker VM
     * @default 12GB
     */
    readonly firecrackerMemory?: string;
    /**
     * The number of CPUs to give to each firecracker VM
     * @default 4
     */
    readonly firecrackerNumCpus?: number;
    /**
     * DEPRECATED. This is not used anymore.
     * @default 0.0.0.0/0
     */
    readonly httpAccessCidrRange?: string;
    /**
     * A label tag to add to all the executors. Can be used for filtering out the right instances in stackdriver monitoring.
     */
    readonly instanceTag: string;
    /**
     * The amount of memory to allocate to each virtual machine or container
     * @default 12GB
     */
    readonly jobMemory?: string;
    /**
     * The number of CPUs to allocate to each virtual machine or container
     * @default 4
     */
    readonly jobNumCpus?: number;
    /**
     * The amount of jobs a single instance should have in queue. Used for autoscaling.
     * @default 360
     */
    readonly jobsPerInstanceScaling?: number;
    /**
     * Executor node machine disk image to use for creating the boot volume. Leave empty to use latest compatible with the Sourcegraph version.
     */
    readonly machineImage?: string;
    /**
     * Executor node machine type.
     * @default c5n.metal
     */
    readonly machineType?: string;
    /**
     * The maximum time that can be spent by the worker dequeueing records to be handled
     * @default 2h
     */
    readonly maxActiveTime?: string;
    /**
     * The maximum number of executor instances to run in the autoscaling group.
     * @default 1
     */
    readonly maxReplicas?: number;
    /**
     * The number of jobs to run concurrently per executor instance
     * @default 18
     */
    readonly maximumNumJobs?: number;
    /**
     * The maximum wall time that can be spent on a single job
     * @default 30m
     */
    readonly maximumRuntimePerJob?: string;
    /**
     * If provided, the default security groups will not be created. The ID of the security group to associate the Launch Template network with.
     */
    readonly metricsAccessSecurityGroupId?: string;
    /**
     * The value for environment by which to filter the custom metrics.
     */
    readonly metricsEnvironmentLabel: string;
    /**
     * The minimum number of executor instances to run in the autoscaling group.
     * @default 1
     */
    readonly minReplicas?: number;
    /**
     * The maximum number of jobs that will be dequeued by the worker
     * @default 1800
     */
    readonly numTotalJobs?: number;
    /**
     * If not provided, there will be no permissions boundary on IAM roles and users created. The ARN of a policy to use for permissions boundaries with IAM roles and users.
     */
    readonly permissionsBoundaryArn?: string;
    /**
     * Whether to use preemptible machines instead of standard machines; usually way cheaper but might be terminated at any time
     */
    readonly preemptibleMachines?: boolean;
    /**
     * The queue from which the executor should dequeue jobs.
     */
    readonly queueName: string;
    /**
     * Use randomized names for resources. Deployments using the legacy naming convention will be updated in-place with randomized names when enabled.
     */
    readonly randomizeResourceNames: boolean;
    /**
     * An optional prefix to add to all resources created.
     */
    readonly resourcePrefix?: string;
    /**
     * The shared password used to authenticate requests to the internal executor proxy.
     */
    readonly sourcegraphExecutorProxyPassword: string;
    /**
     * The externally accessible URL of the target Sourcegraph instance.
     */
    readonly sourcegraphExternalUrl: string;
    /**
     * CIDR range from where SSH access to the EC2 instances is acceptable.
     * @default 10.0.0.0/16
     */
    readonly sshAccessCidrRange?: string;
    /**
     * The ID of the subnet within the given VPC to run the instance in.
     */
    readonly subnetId: string;
    /**
     * Whether to isolate commands in virtual machines
     * @default true
     */
    readonly useFirecracker?: boolean;
    /**
     * The ID of the VPC to run the instance in.
     */
    readonly vpcId: string;
}
/**
 * Defines an ExecutorsExecutors based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/sourcegraph/executors/aws/~> 5.0.1/submodules/executors sourcegraph/executors/aws//modules/executors}
 */
export declare class ExecutorsExecutors extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: ExecutorsExecutorsConfig);
    get assignPublicIp(): boolean | undefined;
    set assignPublicIp(value: boolean | undefined);
    get bootDiskIops(): number | undefined;
    set bootDiskIops(value: number | undefined);
    get bootDiskSize(): number | undefined;
    set bootDiskSize(value: number | undefined);
    get bootDiskThroughput(): number | undefined;
    set bootDiskThroughput(value: number | undefined);
    get dockerAuthConfig(): string | undefined;
    set dockerAuthConfig(value: string | undefined);
    get dockerRegistryMirror(): string | undefined;
    set dockerRegistryMirror(value: string | undefined);
    get dockerRegistryMirrorNodeExporterUrl(): string | undefined;
    set dockerRegistryMirrorNodeExporterUrl(value: string | undefined);
    get firecrackerDiskSpace(): string | undefined;
    set firecrackerDiskSpace(value: string | undefined);
    get firecrackerMemory(): string | undefined;
    set firecrackerMemory(value: string | undefined);
    get firecrackerNumCpus(): number | undefined;
    set firecrackerNumCpus(value: number | undefined);
    get httpAccessCidrRange(): string | undefined;
    set httpAccessCidrRange(value: string | undefined);
    get instanceTag(): string;
    set instanceTag(value: string);
    get jobMemory(): string | undefined;
    set jobMemory(value: string | undefined);
    get jobNumCpus(): number | undefined;
    set jobNumCpus(value: number | undefined);
    get jobsPerInstanceScaling(): number | undefined;
    set jobsPerInstanceScaling(value: number | undefined);
    get machineImage(): string | undefined;
    set machineImage(value: string | undefined);
    get machineType(): string | undefined;
    set machineType(value: string | undefined);
    get maxActiveTime(): string | undefined;
    set maxActiveTime(value: string | undefined);
    get maxReplicas(): number | undefined;
    set maxReplicas(value: number | undefined);
    get maximumNumJobs(): number | undefined;
    set maximumNumJobs(value: number | undefined);
    get maximumRuntimePerJob(): string | undefined;
    set maximumRuntimePerJob(value: string | undefined);
    get metricsAccessSecurityGroupId(): string | undefined;
    set metricsAccessSecurityGroupId(value: string | undefined);
    get metricsEnvironmentLabel(): string;
    set metricsEnvironmentLabel(value: string);
    get minReplicas(): number | undefined;
    set minReplicas(value: number | undefined);
    get numTotalJobs(): number | undefined;
    set numTotalJobs(value: number | undefined);
    get permissionsBoundaryArn(): string | undefined;
    set permissionsBoundaryArn(value: string | undefined);
    get preemptibleMachines(): boolean | undefined;
    set preemptibleMachines(value: boolean | undefined);
    get queueName(): string;
    set queueName(value: string);
    get randomizeResourceNames(): boolean;
    set randomizeResourceNames(value: boolean);
    get resourcePrefix(): string | undefined;
    set resourcePrefix(value: string | undefined);
    get sourcegraphExecutorProxyPassword(): string;
    set sourcegraphExecutorProxyPassword(value: string);
    get sourcegraphExternalUrl(): string;
    set sourcegraphExternalUrl(value: string);
    get sshAccessCidrRange(): string | undefined;
    set sshAccessCidrRange(value: string | undefined);
    get subnetId(): string;
    set subnetId(value: string);
    get useFirecracker(): boolean | undefined;
    set useFirecracker(value: boolean | undefined);
    get vpcId(): string;
    set vpcId(value: string);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
