import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface ExecutorsNetworkingConfig extends TerraformModuleUserConfig {
    /**
     * The availability zone to create the network in.
     */
    readonly availabilityZone: string;
    /**
     * When true, the network will contain a NAT router. Use when executors should not get public IPs.
     */
    readonly nat?: boolean;
    /**
     * Use randomized names for resources. Deployments using the legacy naming convention will be updated in-place with randomized names when enabled.
     */
    readonly randomizeResourceNames: boolean;
    /**
     * An optional prefix to add to all resources created.
     */
    readonly resourcePrefix?: string;
}
/**
 * Defines an ExecutorsNetworking based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/sourcegraph/executors/aws/~> 5.0.1/submodules/networking sourcegraph/executors/aws//modules/networking}
 */
export declare class ExecutorsNetworking extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: ExecutorsNetworkingConfig);
    get availabilityZone(): string;
    set availabilityZone(value: string);
    get nat(): boolean | undefined;
    set nat(value: boolean | undefined);
    get randomizeResourceNames(): boolean;
    set randomizeResourceNames(value: boolean);
    get resourcePrefix(): string | undefined;
    set resourcePrefix(value: string | undefined);
    get ipCidrOutput(): string;
    get natIpOutput(): string;
    get subnetIdOutput(): string;
    get vpcIdOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
